.. SPDX-FileCopyrightText: Copyright © 2024 Idiap Research Institute <contact@idiap.ch>
..
.. SPDX-License-Identifier: GPL-3.0-or-later

.. _mednet.databases:

===========
 Databases
===========

:ref:`Databases <mednet.datamodel>` are categorized by tasks.

.. toctree::
   :maxdepth: 2

   classify/index
   segment/index
   detect/index
